Learn R Programming

conting (version 1.4)

ScotPWID: People Who Inject Drugs in Scotland 2006: An Incomplete 2^7 Table

Description

5670 people who inject drugs (PWID) in Scotland in 2006 are osberved by four sources: social enquiry reports (S1), hospital records (S2), Scottish drug misuse database (S3) and Hepatitis C virus (HCV) diagnosis database (S4). The PWID are further cross-classified according to three additional factors: region (Region; 2 levels), gender (Gender; 2 levels) and age (Age; 2 levels).

Usage

data(ScotPWID)

Arguments

source

King, R., Bird, S. M., Overstall, A. M., Hay, G. & Hutchinson, S. J. (2013) Injecting drug users in Scotland, 2006: Listing, number, demography, and opiate-related death-rates. Addiction Research and Theory, 21 (3), 235-246.

Details

Note that the PWID observed by source S4, the HCV database, are not necessarily current PWID. They are people who have a history of drug use. Therefore the count in the cell corresponding to only being observed by the HCV database is an overcount. Overstall et al (2014) use a modelling approach whereby the count in the cell corresponding to only being observed by the HCV database is missing and the observed value acts as an upper bound. For more details on the dataset see King et al (2013). For details on the function bict applied to this data, see Overstall & King (2014).

References

Overstall, A.M., King, R., Bird, S.M., Hutchinson, S.J. & Hay, G. (2014) Incomplete contingency tables with censored cells with application to estimating the number of people who inject drugs in Scotland. Statistics in Medicine, 33 (9), 1564--1579. Overstall, A.M. & King, R. (2014) conting: An R package for Bayesian analysis of complete and incomplete contingency tables. Journal of Statistical Software, 58 (7), 1--27. http://www.jstatsoft.org/v58/i07/

Examples

Run this code
data(ScotPWID)
summary(ScotPWID)

Run the code above in your browser using DataLab