Learn R Programming

conting (version 1.4)

plot.pval: Plot pval Objects

Description

This function plots objects of class "pval".

Usage

## S3 method for class 'pval':
plot(x, ...)

Arguments

x
An object of class "pval".
...
Arguments to be passed to and from other methods.

Value

  • This function will produce a plot of T_obs against T_pred (see bayespval) along with a line through the origin with slope one. The proportion of points above the line (grey points) gives the Bayesian p-value.

See Also

bayespval