Learn R Programming

conting (version 1.4)

print.acceptrate: Prints acceptrate Objects

Description

This function prints objects of class "acceptrate".

Usage

## S3 method for class 'acceptrate':
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
An object of class "acceptrate".
digits
An optional argument controlling the rounding of output.
...
Arguments to be passed to and from other methods.

Value

  • This function will simply print out the acceptance rates for the reversible jump and Metropolis-Hastings algorithms.

See Also

accept_rate