bcct and bict Objects"bcct" and "bict".## S3 method for class 'bcct':
print(x, ...)
## S3 method for class 'bict':
print(x, ...)"bcct" or "bict".bcct or bict objects.
They display the number of cells in the table, the maximal model considered, the number of
log-linear parameters in the maximal model, the number of MCMC iterations, the computer time
required for the MCMC (in hours, minutes and seconds) and the prior used.
In the case of objects of class "bict", it also prints out the number of missing and
censored cells.bcct,
bict.