Learn R Programming

conting (version 1.4)

print.interstat: Print interstat Objects

Description

This function prints objects of class "interstat".

Usage

## S3 method for class 'interstat':
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
An object of class "interstat".
digits
An optional argument controlling the rounding of output.
...
Arguments to be passed to and from other methods.

Value

  • This function will print out the posterior probability, posterior mean, posterior variance and the 100*prob.level% highest posterior density intervals (HPDIs) of each log-linear parameter (subject to the argument cutoff).

See Also

inter_stats.