Learn R Programming

conting (version 1.4)

print.modprobs: Print modprobs Objects

Description

This function prints objects of class "modprobs".

Usage

## S3 method for class 'modprobs':
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
An object of class "modprobs".
digits
An optional argument controlling the rounding of output.
...
Arguments to be passed to and from other methods.

Value

  • This function will print out the posterior model probability of the "best" models as defined by the arguments best or scale.

See Also

mod_probs.