Learn R Programming

conting (version 1.4)

print.totpop: Print totpop Objects

Description

This function prints objects of class "totpop".

Usage

## S3 method for class 'totpop':
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
An object of class "totpop".
digits
An optional argument controlling the rounding of output.
...
Arguments to be passed to and from other methods.

Value

  • The function will print out the posterior mean and the 100*prob.level% highest posterior density interval for the total population size.

See Also

total_pop.