S1), hospital records (S2),
Scottish drug misuse database (S3) and Hepatitis C virus (HCV) diagnosis
database (S4). The PWID are further cross-classified according to three
additional factors: region (Region; 2 levels), gender (Gender; 2
levels) and age (Age; 2 levels).data(ScotPWID)S4, the HCV database, are not necessarily current
PWID. They are people who have a history of drug use. Therefore the count in the cell
corresponding to only being observed by the HCV database is an overcount. Overstall et al
(2014) use a modelling approach whereby the count in the cell corresponding to only being
observed by the HCV database is missing and the observed value acts as an upper bound. For
more details on the dataset see King et al (2013).
For details on the function bict applied to this data, see Overstall & King (2014).data(ScotPWID)
summary(ScotPWID)Run the code above in your browser using DataLab