Rdocumentation
powered by
Learn R Programming
conting (version 1.4)
plot.totpop: Plot
totpop
Objects
Description
This function plots objects of class
"totpop"
.
Usage
## S3 method for class 'totpop': plot(x, ...)
Arguments
x
An object of class
"totpop"
.
...
Arguments to be passed to and from other methods.
Value
This function will produce a histogram of the MCMC sample from the posterior distribution of the total population size.
See Also
total_pop