print.pval: Print pval Objects
Description
This function prints objects of class "pval".Usage
## S3 method for class 'pval':
print(x, digits = max(3, getOption("digits") - 3), ...)Arguments
x
An object of class "pval".
digits
An optional argument controlling the rounding of output.
...
Arguments to be passed to and from other methods.
Value
- This function will print out summary statistics for the predictive (
T_pred) and
observed (T_obs) discrepancy statistics. Additionally it will output the associated
Bayesian p-value.