print.submod: Print submod Objects
Description
This function prints objects of class "submod".Usage
## S3 method for class 'submod':
print(x, ..., digits = max(3, getOption("digits") - 3))Arguments
x
An object of class "submod".
...
Arguments to be passed to and from other methods.
digits
An optional argument controlling the rounding of output.
Value
- Firstly, conditional on the model of interest (defined by
formula and order),
this function will print out the posterior means, posterior variances and 100*prob.level%
highest posterior density intervals (HPDIs) for each of the log-linear parameters. Secondly, conditional
on the model of interest, it will print out summaries of the discrepancy statistics and the
corresponding Bayesian p-value. Finally, if the class of the object passed to sub_model is
"bict", then it will print out the posterior mean and 100*prob.level% HPDI for the total
population size, conditional on the model of interest.